/*
 Copyright (c) 2014 by Plexim GmbH
 All rights reserved.

 NOTICE: This software embodies unpublished proprietary
 and trade secret information of Plexim GmbH.  Any copying,
 disclosure or transmission not expressly authorized by
 the owner is expressly prohibited. Plexim GmbH retains exclusive
 ownership of all intellectual property rights in this software,
 including all copyright, trade secret and patent rights.
 */

/**
 * @file pi.h
 * @brief Basic PI-Regulator with anti-windup.
 */

#ifndef PI_H_
#define PI_H_

#include "plx_types.h"

#ifdef __cplusplus
extern "C" {
#endif

// fixed-point references
#define PLX_PI_Q_KP 10
#define PLX_PI_R_KP 1024
#define PLX_PI_Q_KI 14
#define PLX_PI_R_KI 16384

typedef struct PLX_PI_OBJ
{
	int16_t data[8];
} PLX_PI_Obj_t;

typedef struct PLX_PI_Obj_t *PLX_PI_Handle_t;

extern PLX_PI_Handle_t PLX_PI_init(void *aMemory, const size_t aNumBytes);

extern void PLX_PI_configure(PLX_PI_Handle_t aPiHandle, int16_t aKp, int16_t aKi);

extern void PLX_PI_reset(PLX_PI_Handle_t aPiHandle);

extern void PLX_PI_calculateOutput(PLX_PI_Handle_t aPiHandle, int16_t aError, int16_t *aOut);

extern void PLX_PI_updateIntegrator(PLX_PI_Handle_t aPiHandle, int16_t aOutLimited);

#ifdef __cplusplus
}
#endif // extern "C"

#endif /* PI_H_ */
