<?php
/*
 *  model_functions.php
 *
 *  Copyright (c) 2014 Plexim GmbH. All rights reserved.
 *
 * $Rev: 15281 $
 * $Date: 2015-06-09 11:26:25 +0200 (Tue, 09 Jun 2015) $
 */
 
require 'general_functions.php';


function processModelCallback()
{
   $action = urlVar('action');
   $args = array();
   switch ($action)
   {
      case 'loadModel':
         $retData = loadModel();
         break;
      case 'startAnalysis':
         $args["analysisName"] = urlVar('analysisName');
      case 'startSimulation':
         $args = array_merge(simulationParameters(), $args);
      case 'stopSimulation':
      case 'abortAnalysis':
         $retData = plecsWebserver($action, uniqueModelName(), $args);
         break;
      case 'getSimulationState':
         $retData = getSimulationState();
         break;
      case 'holdTrace':
         $retData = holdTrace(urlVar('traceName'));
         break;
      case 'getTraceNames':
         $retData = getTraceNames();
         break;
      case 'setVisibleTraces':
         $retData = setVisibleTraces(json_decode(urlVar('traceNames'), true));
         break;
      case 'removeTraces':
         $retData = removeTraces(json_decode(urlVar('traceNames'), true)['traces']);
         break;
   }
   echo json_encode($retData);
}


function loadModel()
{
   getConfigIni();
   $modelRoot = $_SESSION['config_ini']['modelpath'] . '/';
   $fullModelName = fullModelName();
  
   if(!isset($_SESSION['models']))
      $_SESSION['models'] = array();

   if (uniqueModelName())
      plecsXml('plecs.close', uniqueModelName());
  
   $errorMsg = '';
   $configString = '';
   $configFile = $modelRoot.$fullModelName.'.json';
   if (!file_exists($configFile))
      $errorMsg .= "Error: Config file not found: ".$configFile."\n";
   else
   {
      $configString = file_get_contents($configFile, true);
      $_SESSION['models'][$fullModelName] = array();
      $_SESSION['models'][$fullModelName] = json_decode($configString, true);
      if ($_SESSION['models'][$fullModelName] == null)
         $errorMsg .= "Error parsing config file: ".$configFile."\n";
   }

   $modelFile = $modelRoot.$fullModelName.'.plecs';
   if (!file_exists($modelFile))
      $errorMsg .= "Error: Model file not found: ".$modelFile."\n";
   else
   {
      $opts = array('lifetime' => $_SESSION['config_ini']['expirytime']);
      $retData = plecsWebserver('createModelInstance', getcwd().'/'.$modelFile, $opts);
      if (isset($retData['errorMsg']))
         $errorMsg .= $retData['errorMsg'];
      else
         $_SESSION['models'][$fullModelName]['uniqueModelName'] = $retData;
   }

   if ($errorMsg)
      error_log("PHP Error\n".$errorMsg."");
   return array(
      'configStr' => $configString,
      'errorMsg' => $errorMsg,
      'SID' => htmlspecialchars(SID)
   );
}


function getSimulationState()
{
   $retData = plecsWebserver('getSimulationState', uniqueModelName());
   if (!isset($retData['errorMsg']))
   {
      if (isset($retData['errorMessage']))
      {
         $retData['errorMsg'] = preg_replace('/Error: Assertion failed in [^:]+: /', '', $retData['errorMessage']);
         unset($retData['errorMessage']);
      }
   }
   return $retData;
}


function simulationParameters()
{
   global $post_data;
   
   $paramTables = $_SESSION['models'][fullModelName()]['paramtables'];
   if (!isset($post_data['prm']))
      return;
   $paramValues = $post_data['prm'];
   $nParamsTables = count($paramTables);
   $p = 0;
   for ($i = 0; $i < $nParamsTables; $i++)
   {
      $nParams = count($paramTables[$i]['parameters']);
      for ($j = 0; $j < $nParams; $j++)
      {
         $param = $paramTables[$i]['parameters'][$j];
         $paramValue = $paramValues[$p++];
         if (isset($param['type']) &&
             ($param['type'] == 'combobox' || $param['type'] == 'radio' || $param['type'] == 'checkbox'))
         {
            $modelVars[$param['variable']] = new xmlrpcval($paramValue, is_numeric($paramValue) ? "double" : "string");
            if (isset($param['addvariables']) && is_array($param['addvariables']))
            {
               for ($o = 0; $o < count($param['options']); $o++)
               {
                  if ($paramValue == $param['options'][$o]['value'])
                  {
                     for ($a = 0; $a < count($param['addvariables']); $a++)
                     {
                        if (isset($param['options'][$o]['addvalues'][$a]))
                           $addvalue = $param['options'][$o]['addvalues'][$a];
                        else
                           $addvalue = '';
                        $modelVars[$param['addvariables'][$a]] = new xmlrpcval($addvalue, is_numeric($addvalue) ? "double" : "string");
                     }
                  }
               }
            }
         }
         else if (isset($param['type']) && $param['type'] == 'text')
         {
            $modelVars[$param['variable']] = new xmlrpcval($paramValue, "string");
         }
         else if (!isset($param['multiple']) || !$param['multiple'])
         {
            if (!is_numeric($paramValue))
               exit("Error: Parameter " . $param['variable'] . " must be a numeric value.");
            if (isset($param['min']) and $paramValue < $param['min'])
               if (isset($param['max']) and $paramValue > $param['max'])
                  exit("Error: Parameter " . $param['variable'] . "must in the interval [" .
                               $param['min'] . "," . $param['max'] . "].");
               else
                  exit("Error: Parameter " . $param['variable'] . " must be less than " .
                               $param['min'] . ".");
            if (isset($param['max']) and $paramValue > $param['max'])
               exit("Error: Parameter " . $param['variable'] . " must be greater than " .
                            $param['max'] . ".");
            $modelVars[$param['variable']] = new xmlrpcval($paramValue, "double");
         }
      }
   }
   return array("ModelVars" => $modelVars);
}


function holdTrace($name)
{
   $scopes = $_SESSION['models'][fullModelName()]['scopes'];
   $nScopes = count($scopes);
   $pathPrefix = uniqueModelName().'/';
   for ($s = 0; $s < $nScopes; $s++)
      plecsScope($pathPrefix.$scopes[$s]['path'], 'HoldTrace', strval($name));
   return array();
}


function getTraceNames()
{
   $scopes = $_SESSION['models'][fullModelName()]['scopes'];
   $nScopes = count($scopes);
   $pathPrefix = uniqueModelName().'/';
   $traceNames = array();
   $min = 0;
   $max = 1e6;
   for ($s = 0; $s < $nScopes; $s++)
   {
      $traceNames[$s] = plecsWebserver('getTraceNames', $pathPrefix.$scopes[$s]['path']);
      $numTraceNames = count($traceNames[$s]);
      if ($numTraceNames > $min)
         $min = $numTraceNames;
      if ($numTraceNames < $max)
         $max = $numTraceNames;
   }
   if ($min != $max)
   {
      for ($s = 0; $s < $nScopes; $s++) 
         plecsScope($pathPrefix.$scopes[$s]['path'], 'ClearTraces');
      return plecsWebserver('getTraceNames', $pathPrefix.$scopes[0]['path']);
   }
   return $traceNames[0];
}


function setVisibleTraces($traceNames) {
   $scopes = $_SESSION['models'][fullModelName()]['scopes'];
   $nScopes = count($scopes);
   $pathPrefix = uniqueModelName().'/';
   for ($s = 0; $s < $nScopes; $s++)
      plecsWebserver('setVisibleTraces', $pathPrefix.$scopes[$s]['path'], $traceNames);
   return array();
}


function removeTraces($traces)
{
   $scopes = $_SESSION['models'][fullModelName()]['scopes'];
   $nScopes = count($scopes);
   $pathPrefix = uniqueModelName().'/';
   $nTraces = count($traces);
   for ($t = 0; $t < $nTraces; $t++)
   {  
      for ($s = 0; $s < $nScopes; $s++)
         plecsScope($pathPrefix.$scopes[$s]['path'], 'RemoveTrace', strval($traces[$t]));
   }
   return array();
}

?>